Description: Wha t is the product of the reaction: a) b)H2CCHCH2CH3 c) d)CH3O. Which of the following compounds is correctly classified as a tertiary alcohol?
Keywords: density,density_flags,dropped,hashtags,meta_keywords,preset_used,primary,raw,secondary,slug_candidates
Date: 2026-04-27T22:57:04.228819Z

# ch102practiceexam2-pages

ch102practiceexam2 page 0002

Wha t is the product of the reaction: a) b)H2CCHCH2CH3 c) d)CH3O. Which of the following compounds is correctly classified as a tertiary alcohol?

density density_flags dropped hashtags meta_keywords preset_used primary raw secondary slug_candidates
License: CC BY-SA 4.0 · Created by The Daily Dialectics for educational purposes · @thedailydialectics · Full image